==> vmd-0.96.tar.gz: vmd-0.96/src/Tokenize.h <==
/***************************************************************************
 *cr                                                                       
 *cr            (C) Copyright 1995 The Board of Trustees of the           
 *cr                        University of Illinois                       
 *cr                         All Rights Reserved                        
 *cr                                                                   
 ***************************************************************************/

/***************************************************************************
 * RCS INFORMATION:
 *
 *	$RCSfile: Tokenize.h,v $
 *	$Author: billh $	$Locker:  $		$State: Exp $
 *	$Revision: 1.2 $	$Date: 95/03/24 18:52:01 $
 *
 ***************************************************************************
 * DESCRIPTION:
 * Simple tokenizing class
 * given a string, makes an array of all the tokens needed
 *
 ***************************************************************************
 * REVISION HISTORY:
 *
 * $Log:	Tokenize.h,v $
 * Revision 1.2  95/03/24  18:52:01  billh
 * Added copyright notice to top of file; made sure all virtual routines
 * are defined in the .C file, not in the .h file.
 * 
 * Revision 1.1  1994/11/12  10:23:51  dalke
 * Initial revision
 *
 ***************************************************************************/

#ifndef TOKENIZE_H
#define TOKENIZE_H

#include "ResizeArray.h"

// Can I derive this from a template?

class Tokenize {
public:
  ResizeArray<char *> tokens;
private:
  char *datastr;

public:
  Tokenize(char *data, char *delimiters);  
  ~Tokenize(void);
  int num(void) { return tokens.num(); }
  char *item(int n) { return tokens.item(n); }
};

#endif

==> vmd-0.97.tar.gz: vmd-0.97/src/Tokenize.h <==
/***************************************************************************
 *cr                                                                       
 *cr            (C) Copyright 1995 The Board of Trustees of the           
 *cr                        University of Illinois                       
 *cr                         All Rights Reserved                        
 *cr                                                                   
 ***************************************************************************/

/***************************************************************************
 * RCS INFORMATION:
 *
 *	$RCSfile: Tokenize.h,v $
 *	$Author: billh $	$Locker:  $		$State: Exp $
 *	$Revision: 1.3 $	$Date: 1995/05/11 23:57:14 $
 *
 ***************************************************************************
 * DESCRIPTION:
 * Simple tokenizing class
 * given a string, makes an array of all the tokens needed
 *
 ***************************************************************************/
#ifndef TOKENIZE_H
#define TOKENIZE_H

#include "ResizeArray.h"


class Tokenize {
public:
  ResizeArray<char *> tokens;
private:
  char *datastr;

public:
  Tokenize(char *data, char *delimiters);  
  ~Tokenize(void);
  int num(void) { return tokens.num(); }
  char *item(int n) { return tokens.item(n); }
};

#endif

/* REVISION HISTORY:********************************************************
 *
 * $Log: Tokenize.h,v $
 * Revision 1.3  1995/05/11  23:57:14  billh
 * Moved log messages to end of file.
 *
 * Revision 1.2  95/03/24  18:52:01  billh
 * Added copyright notice to top of file; made sure all virtual routines
 * are defined in the .C file, not in the .h file.
 * 
 * Revision 1.1  1994/11/12  10:23:51  dalke
 * Initial revision
 *
 ***************************************************************************/
